===============
wagtailsettings
===============

A plugin for Wagtail that adds developer-defined settings to the admin.

Installing
==========

Install using pip::

    pip install wagtailsettings

It is compatible with Wagtail 1.0 and upwards, Python

Documentation
=============

Refer to the ` ``wagtailsettings`` documentation on ReadTheDocs <https://wagtailsettings.readthedocs.org/en/latest/>`_.
